@@ -38,7 +38,7 @@ from ._frames import (
 from ._log_levels import _NAME_TO_LEVEL, add_log_level
 from ._utils import get_processname
 from .tracebacks import ExceptionDictTransformer
-from .types import EventDict, ExceptionTransformer, ExcInfo, WrappedLogger
+from .typing import EventDict, ExceptionTransformer, ExcInfo, WrappedLogger
 
 
 __all__ = [
@@ -183,7 +183,7 @@ def _items_sorter(
 
         def ordered_items(event_dict: EventDict) -> list[tuple[str, Any]]:
             items = []
-            for key in key_order:  # type: ignore
+            for key in key_order:  # type: ignore[union-attr]
                 value = event_dict.pop(key, None)
                 if value is not None or not drop_missing:
                     items.append((key, value))
@@ -196,7 +196,7 @@ def _items_sorter(
 
         def ordered_items(event_dict: EventDict) -> list[tuple[str, Any]]:
             items = []
-            for key in key_order:  # type: ignore
+            for key in key_order:  # type: ignore[union-attr]
                 value = event_dict.pop(key, None)
                 if value is not None or not drop_missing:
                     items.append((key, value))
@@ -211,7 +211,9 @@ def _items_sorter(
             return sorted(event_dict.items())
 
     else:
-        ordered_items = operator.methodcaller("items")  # type: ignore
+        ordered_items = operator.methodcaller(  # type: ignore[assignment]
+            "items"
+        )
 
     return ordered_items
 
@@ -410,7 +412,7 @@ This behavior is analogue to the one of the stdlib's logging.
 dict_tracebacks = ExceptionRenderer(ExceptionDictTransformer())
 """
 Replace an ``exc_info`` field with an ``exception`` field containing structured
-tracebacks suiteable for, e.g., JSON output.
+tracebacks suitable for, e.g., JSON output.
 
 It is a shortcut for :class:`ExceptionRenderer` with a
 :class:`~structlog.tracebacks.ExceptionDictTransformer`.
@@ -507,7 +509,7 @@ def _make_stamper(
         return stamper_iso_local
 
     def stamper_fmt(event_dict: EventDict) -> EventDict:
-        event_dict[key] = now().strftime(fmt)  # type: ignore
+        event_dict[key] = now().strftime(fmt)  # type: ignore[arg-type]
 
         return event_dict
 
@@ -522,9 +524,9 @@ def _figure_out_exc_info(v: Any) -> ExcInfo:
     if isinstance(v, BaseException):
         return (v.__class__, v, v.__traceback__)
     elif isinstance(v, tuple):
-        return v  # type: ignore
+        return v  # type: ignore[return-value]
     elif v:
-        return sys.exc_info()  # type: ignore
+        return sys.exc_info()  # type: ignore[return-value]
 
     return v
 
@@ -585,11 +587,11 @@ class StackInfoRenderer:
     of the Python standard library logging.
 
     :param additional_ignores: By default, stack frames coming from
-        ``structlog`` are ignored. With this argument you can add additional
+        *structlog* are ignored. With this argument you can add additional
         names that are ignored, before the stack starts being rendered. They
         are matched using ``startswith()``, so they don't have to match
         exactly. The names are used to find the first relevant name, therefore
-        once a frame is found that doesn't start with ``structlog`` or one of
+        once a frame is found that doesn't start with *structlog* or one of
         *additional_ignores*, **no filtering** is applied to subsequent frames.
 
     .. versionadded:: 0.4.0
@@ -628,7 +630,7 @@ class CallsiteParameter(enum.Enum):
     #: The basename part of the full path to the python source file of the
     #: callsite.
     FILENAME = "filename"
-    #: The python module the callsite was in. This mimicks the module attribute
+    #: The python module the callsite was in. This mimics the module attribute
     #: of `logging.LogRecord` objects and will be the basename, without
     #: extension, of the full path to the python source file of the callsite.
     MODULE = "module"
@@ -658,7 +660,7 @@ class CallsiteParameterAdder:
         async functions.
 
     If the event dictionary has an embedded `logging.LogRecord` object and did
-    not originate from `structlog` then the callsite information will be
+    not originate from *structlog* then the callsite information will be
     determined from the `logging.LogRecord` object. For event dictionaries
     without an embedded `logging.LogRecord` object the callsite will be
     determined from the stack trace, ignoring all intra-structlog calls, calls
@@ -810,6 +812,8 @@ class EventRenamer:
         handled gracefully.
 
     .. versionadded:: 22.1
+
+    See also the :ref:`rename-event` recipe.
     """
 
     def __init__(self, to: str, replace_by: str | None = None):
